%define        libname libicu
%define        pkgver  %(echo %version | tr '.' '_')

Name:          icu
Version:       62.1
Release:       1mamba
Summary:       Set of C/C++ and Java libraries for Unicode support
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           http://www.icu-project.org
Source:        http://download.icu-project.org/files/icu4c/%{version}/icu4c-%{pkgver}-src.tgz
Patch0:        %{name}-4.4-ctestfw-makefilein.patch
Patch1:        %{name}-4.4.1-arm_assembly.patch
License:       MIT
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END
Requires:      %{libname} = %{version}-%{release}
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
ICU is a set of C/C++ and Java libraries that provides robust and full-featured Unicode and locale support.
The library provides calendar support, conversions for many character sets, language sensitive collation, date and time formatting, support for many locales, message catalogs and resources, message formatting, normalization, number and currency formatting, time zones support, transliteration, word, line and sentence breaking, etc.

This package contains the Unicode character database and derived properties, along with converters and time zones data.

%package -n %{libname}
Group:         System/Libraries
Summary:       Set of C/C++ and Java libraries for Unicode support

%description -n %{libname}
ICU is a set of C/C++ and Java libraries that provides robust and full-featured Unicode support, software internationalization and globalization (i18n/g11n).
ICU is widely portable and gives applications the same results on all platforms and between C/C++ and Java software.

This package contains the runtime libraries for ICU.

%package -n %{libname}-devel
Group:         Development/Libraries
Summary:       Static libraries and headers for ICU
Requires:      %{libname} = %{version}-%{release}

%description -n %{libname}-devel
ICU is a set of C/C++ and Java libraries that provides robust and full-featured Unicode support, software internationalization and globalization (i18n/g11n).
ICU is widely portable and gives applications the same results on all platforms and between C/C++ and Java software.

This package contains static libraries and header files need for development.

%prep
%setup -q -n %{name}
#%patch0 -p1
#%patch1 -p1

%build
cd source

%configure \
   --enable-shared \
   --enable-static \
   --disable-samples

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall -C source

# fix wrong libraries permissions
chmod +x %{buildroot}%{_libdir}/*.so.*

rm -f %{buildroot}%{_datadir}/icu/%{version}/license.html

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/derb
%{_bindir}/gen*
%{_bindir}/icuinfo
%{_bindir}/makeconv
%{_bindir}/pkgdata
%{_bindir}/uconv
%{_sbindir}/escapesrc
%{_sbindir}/gen*
%{_sbindir}/icupkg
%{_mandir}/man?/*
%doc license.html readme.html

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files -n %{libname}-devel
%defattr(-,root,root)
%{_bindir}/icu-config
%dir %{_datadir}/icu
%dir %{_datadir}/icu/%{version}
%dir %{_datadir}/icu/%{version}/config
%{_datadir}/icu/%{version}/LICENSE
%{_datadir}/icu/%{version}/mkinstalldirs
%{_datadir}/icu/%{version}/config/mh-linux
%{_datadir}/icu/%{version}/install-sh
%dir %{_includedir}/unicode
#%dir %{_includedir}/layout
#%{_includedir}/layout/*.h
%{_includedir}/unicode/*.h
%{_libdir}/*.a
%{_libdir}/*.so
%dir %{_libdir}/icu
%dir %{_libdir}/icu/%{version}
%{_libdir}/icu/current
%{_libdir}/icu/%{version}/Makefile.inc
%{_libdir}/icu/Makefile.inc
%{_libdir}/icu/%{version}/pkgdata.inc
%{_libdir}/icu/pkgdata.inc
%{_libdir}/pkgconfig/icu-*.pc

%changelog
* Thu Aug 09 2018 Automatic Build System <autodist@mambasoft.it> 62.1-1mamba
- automatic version update by autodist

* Fri Mar 30 2018 Automatic Build System <autodist@mambasoft.it> 61.1-1mamba
- automatic version update by autodist

* Wed Dec 20 2017 Automatic Build System <autodist@mambasoft.it> 60.2-1mamba
- automatic version update by autodist

* Fri Jul 21 2017 Automatic Build System <autodist@mambasoft.it> 59.1-1mamba
- automatic version update by autodist

* Thu Dec 15 2016 Automatic Build System <autodist@mambasoft.it> 58.2-1mamba
- automatic version update by autodist

* Tue Apr 19 2016 Automatic Build System <autodist@mambasoft.it> 57.1-1mamba
- automatic version update by autodist

* Tue Nov 03 2015 Automatic Build System <autodist@mambasoft.it> 56.1-1mamba
- automatic version update by autodist

* Thu Apr 09 2015 Automatic Build System <autodist@mambasoft.it> 55.1-1mamba
- automatic version update by autodist

* Tue Oct 21 2014 Automatic Build System <autodist@mambasoft.it> 54.1-1mamba
- automatic version update by autodist

* Fri Apr 18 2014 Automatic Build System <autodist@mambasoft.it> 53.1-1mamba
- automatic version update by autodist

* Thu Oct 17 2013 Automatic Build System <autodist@mambasoft.it> 52.1-1mamba
- automatic version update by autodist

* Sat May 25 2013 Automatic Build System <autodist@mambasoft.it> 51.2-1mamba
- automatic version update by autodist

* Tue Mar 26 2013 Automatic Build System <autodist@mambasoft.it> 51.1-1mamba
- automatic version update by autodist

* Wed Jan 23 2013 Automatic Build System <autodist@mambasoft.it> 50.1.2-1mamba
- automatic version update by autodist

* Tue Dec 18 2012 Automatic Build System <autodist@mambasoft.it> 50.1.1-1mamba
- automatic version update by autodist

* Sun Dec 02 2012 Automatic Build System <autodist@mambasoft.it> 50.1-1mamba
- automatic version update by autodist

* Mon Jul 12 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 4.4.1-1mamba
- update to 4.4.1

* Tue Jun 29 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 4.4-2mamba
- added patch to fix install of libtestfw library required by icutest tool

* Tue Mar 23 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 4.4-1mamba
- update to 4.4

* Tue Dec 09 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 4.0-1mamba
- update to 4.0

* Thu Oct 18 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8-1mamba
- update to 3.8

* Thu Jan 12 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 3.2-2qilnx
- fixed license

* Tue May 31 2005 Davide Madrisan <davide.madrisan@qilinux.it> 3.2-1qilnx
- package created by autospec
